Guides layer for "rasterly".
rasterly_guides(
rastObj,
x_pretty = NULL,
y_pretty = NULL,
panel_background = "grey92",
panel_line = "white"
)A "rasterly" object.
The pretty on x. Compute a sequence of about n+1 equally spaced 'round' values
which cover the range of the values in x. If it is not provided, x_pretty will
be generated by the x range
The pretty on y.
Panel background.
Panel line color
When an image has a 'complicated' background, the drawing time increases significantly.
So it is not recommended. A suggestion to draw grid guides is to transform image data to a data frame
via image2data, then use ggplot or plotly to display.